Module commands

Module commands 

Structs

BuiltNode
A node specification built with NodeBuilder
NodeBuilder
Builder for constructing new nodes to pass to commands.

Enums

Command
A structural mutation command queued during plugin execution. Applied after the plugin finishes (same as JS).
NewNode
A new node to be inserted into the arena. The builder in PluginContext creates these to queue as patches applied in place.