NodeBuilder

Struct NodeBuilder 

pub struct NodeBuilder { /* private fields */ }
Builder for constructing new nodes to pass to commands.

Implementations

Source

impl NodeBuilder

pub fn new(node_type: MdastNodeType) -> Self

pub fn child(self, child: NewNode) -> Self

Add a child node (another builder or raw string)

pub fn children(self, children: impl IntoIterator<Item = NewNode>) -> Self

Add multiple children

pub fn data_bytes(self, bytes: Vec<u8>) -> Self

Set raw type-data bytes (use codec encode_* functions)

pub fn build(self) -> NewNode

Finalize into a NewNode

Source

impl NodeBuilder

Convenience constructors

pub fn heading(depth: u8) -> Self

pub fn paragraph() -> Self

pub fn text(value_offset: u32, value_len: u32) -> Self

pub fn raw(markdown: impl Into<String>) -> NewNode

Create a text node with a raw string (for when we don’t have source offsets) This uses NewNode::Raw internally