Structs
- DataMap
- Untyped data map: maps (node_id, key) → DataValue. This is the Rust-side of the JS node.data map. When a JS plugin runs after a Rust plugin, this gets synced to the JS DataMap.
- Typed
Data Map - Typed data map: stores strongly-typed data keyed by TypeId + node_id. Rust-only, never crosses to JS.
Enums
- Data
Value - A value that can be stored in the untyped data map (interoperable with JS node.data).