Skip to main contentModule commands
Source - BuiltNode
- A node specification built with NodeBuilder
- NodeBuilder
- Builder for constructing new nodes to pass to commands.
- Command
- A structural mutation command queued during plugin execution.
Applied after the plugin finishes (same as JS).
- NewNode
- A new node to be inserted into the arena.
In Phase 5, this is a simple enum. The builder in PluginContext
creates these to queue for arena rebuild.